==> jc-1.4.0.tar.gz: java/rmi/activation/ActivationGroupDesc__24CommandEnvironment.h <==
// public class java.rmi.activation.ActivationGroupDesc$CommandEnvironment

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 54b5b56f2b7c1aad java_rmi_activation_ActivationGroupDesc__24CommandEnvironment

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment_H_
#define _JC_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_refs	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_refs;
typedef struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_nonrefs	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_nonrefs;
typedef struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$refs	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$refs;
typedef struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$nonrefs	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$nonrefs;
typedef struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object;

typedef struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$fields_struct	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$fields_struct;
typedef const struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vmethods	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vmethods;
typedef const struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtable	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtable;
typedef const struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtype	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtype;

// Class fields structure
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$fields_struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$class_fields;

// Constructors
extern void _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method$_init$c23bfa1ec2b2f494(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *);

// Virtual methods
extern jboolean _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *, struct _jc_java_lang_Object$object *);
extern _jc_object_array *_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method$getCommandOptions$ea3c0d56ee2ba248(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *);
extern struct _jc_java_lang_String$object *_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method$getCommandPath$a10935178eb96d6d(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *);
extern jint _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method_info$getCommandOptions$ea3c0d56ee2ba248;
extern _jc_method _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method_info$getCommandPath$a10935178eb96d6d;
extern _jc_method _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *, struct _jc_java_lang_Object$object *);
	_jc_object_array	*(*getCommandOptions$ea3c0d56ee2ba248)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *);
	struct _jc_java_lang_String$object	*(*getCommandPath$a10935178eb96d6d)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *);
};

// Vtable
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vmethods	java_rmi_activation_ActivationGroupDesc__24CommandEnvironment;
};

// Vtype
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_refs {
	struct _jc_java_lang_String$object	*cmdpath;
	_jc_object_array	*argv;
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$refs {
    _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_refs	java_rmi_activation_ActivationGroupDesc__24CommandEnvironment;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_nonrefs	java_rmi_activation_ActivationGroupDesc__24CommandEnvironment;
};

// Object instance structure
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object {
	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtype	*vtype;
	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtype _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_ActivationGroupDesc__24CommandEnvironment, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$class_object;

#endif	/* _JC_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment_H_ */

==> jc-1.4.6.tar.gz: java/rmi/activation/ActivationGroupDesc__24CommandEnvironment.h <==
// public class java.rmi.activation.ActivationGroupDesc$CommandEnvironment

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 54b5b56f2b7c1aad java_rmi_activation_ActivationGroupDesc__24CommandEnvironment

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment_H_
#define _JC_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_refs	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_refs;
typedef struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_nonrefs	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_nonrefs;
typedef struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$refs	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$refs;
typedef struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$nonrefs	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$nonrefs;
typedef struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object;

typedef struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$fields_struct	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$fields_struct;
typedef const struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vmethods	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vmethods;
typedef const struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtable	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtable;
typedef const struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtype	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtype;

// Class fields structure
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$fields_struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$class_fields;

// Constructors
extern void _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method$_init$c23bfa1ec2b2f494(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method$getCommandOptions$ea3c0d56ee2ba248(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method$getCommandPath$a10935178eb96d6d(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *) _JC_JCNI_ATTR;
extern jint _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method_info$getCommandOptions$ea3c0d56ee2ba248;
extern _jc_method _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method_info$getCommandPath$a10935178eb96d6d;
extern _jc_method _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getCommandOptions$ea3c0d56ee2ba248)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getCommandPath$a10935178eb96d6d)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vmethods	java_rmi_activation_ActivationGroupDesc__24CommandEnvironment;
};

// Vtype
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_refs {
	struct _jc_java_lang_String$object	*cmdpath;
	_jc_object_array	*argv;
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$refs {
    _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_refs	java_rmi_activation_ActivationGroupDesc__24CommandEnvironment;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$sub_nonrefs	java_rmi_activation_ActivationGroupDesc__24CommandEnvironment;
};

// Object instance structure
struct _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$object {
	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtype	*vtype;
	_jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$vtype _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_ActivationGroupDesc__24CommandEnvironment, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment$class_object;

#endif	/* _JC_java_rmi_activation_ActivationGroupDesc__24CommandEnvironment_H_ */
